# -*- coding: utf-8 -*-
# @package Merge Sentinel Files
"""
Example:

        $ python -m doctest -v Merge.py
"""

import os,sys
from os.path import expanduser
home = expanduser("~")
a=os.path.join(os.path.expandvars(home),".snap/snap-python/")
sys.path.append(a)
import snappy,numpy
from snappy import jpy,ProductData,ProgressMonitor,ProductUtils
from tools import (tools)
from readProduct import (readProduct)

class Merge(object):
    """ Class for Sentinel satellites configuration
    Test Case
    >>> Files = tools("all") #IW_SLC,IW_GRDH,MSIL1C
    >>> dir="make/"
    >>> platform='Sentinel-2'
    >>> list_files=Files.findFilesSentinel(dir,platform,4)#4 for resample_subset.dim
    >>> print 'There is/are %d ' % len(list_files) + platform + ' file(s)'
    >>> Read=readProduct(dir,platform)
    >>> TypeMerge="RGB"
    >>> Mergee=Merge("60",TypeMerge)
    >>> for image in list_files:
    ...     file = dir + image
    ...     print"Applying SubSet... ", image
    ...     product=Read.ReadFilesSentinel(file,2)#The flag 2 ReadFiles .dim
    ...     Mergee.merges(product, file)
     """

    def __init__(self,ResolSize,TypeMerge):
        """The constructor Initialize Sentinel Data.

        Args:
            self: The object pointer.
            ResolSize (str): destination directory.
            TypeMerge (str): RGB

        Returns:
            pointer: The object pointer.
        """
        self.resolution=ResolSize
        self.ext=".jpg"
        self.Type_Merge="_"+TypeMerge
        self.HashMap = jpy.get_type('java.util.HashMap')
        self.looks = jpy.get_type('org.esa.snap.core.datamodel.quicklooks.QuicklookGenerator')
        self.File = jpy.get_type('java.io.File')
        self.ImageManager = jpy.get_type('org.esa.snap.core.image.ImageManager')
        (self.h, self.w) = (None, None)

    def merges(self, product, file):
        """Index Files Sentinel

         Args:
             self (pointer): The object pointer.
             product (bin): Metadata Sentinel.
             file (str): local path to image.

         """
        blue = product.getBand('B2')
        green = product.getBand('B3')
        red = product.getBand('B4')

        RGB = [red, green, blue]

        info = ProductUtils.createImageInfo(RGB, True, ProgressMonitor.NULL)
        image = ProductUtils.createRgbImage(RGB, info, ProgressMonitor.NULL)

        salida = file[:-4] + self.Type_Merge + self.ext
        savefile = self.File(salida)
        self.looks.writeImage(image, savefile)